Even more devirtualization cleverness.

git-svn-id: https://llvm.org/svn/llvm-project/cfe/trunk@83886 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/lib/CodeGen/CGCXX.cpp b/lib/CodeGen/CGCXX.cpp
index f190679..ff56c8c 100644
--- a/lib/CodeGen/CGCXX.cpp
+++ b/lib/CodeGen/CGCXX.cpp
@@ -210,10 +210,14 @@
     return false;
   }
   
   // We can always devirtualize calls on temporaries.
   if (isa<CXXTemporaryObjectExpr>(Base))
     return true;
   
+  // And calls on bound temporaries.
+  if (isa<CXXBindTemporaryExpr>(Base))
+    return true;
+  
   // Check if this is a call expr that returns a record type.
   if (const CallExpr *CE = dyn_cast<CallExpr>(Base))
     return CE->getCallReturnType()->isRecordType();
@@ -210,10 +210,14 @@
   }
   
-  // We can always devirtualize calls on temporaries.
+  // We can always devirtualize calls on temporary object expressions.
   if (isa<CXXTemporaryObjectExpr>(Base))
     return true;